@@ -16,7 +16,7 @@
 
 namespace QLightDM
 {
-    class PowerInterface : public QObject
+    class Q_DECL_EXPORT PowerInterface : public QObject
     {
         Q_OBJECT
     public:
@@ -34,10 +34,10 @@ namespace QLightDM
         bool canRestart();
 
     public Q_SLOTS:
-        void suspend();
-        void hibernate();
-        void shutdown();
-        void restart();
+        bool suspend();
+        bool hibernate();
+        bool shutdown();
+        bool restart();
 
     private:
         class PowerInterfacePrivate;
