@@ -20,7 +20,7 @@ enum {
 };
 static guint signals[LAST_SIGNAL] = { 0 };
 
-struct DisplayServerPrivate
+typedef struct
 {
     /* TRUE when started */
     gboolean is_ready;
@@ -30,11 +30,12 @@ struct DisplayServerPrivate
 
     /* TRUE when the display server has stopped */
     gboolean stopped;
-};
+} DisplayServerPrivate;
 
 static void display_server_logger_iface_init (LoggerInterface *iface);
 
 G_DEFINE_TYPE_WITH_CODE (DisplayServer, display_server, G_TYPE_OBJECT,
+                         G_ADD_PRIVATE (DisplayServer)
                          G_IMPLEMENT_INTERFACE (LOGGER_TYPE, display_server_logger_iface_init))
 
 const gchar *
@@ -92,14 +93,16 @@ display_server_start (DisplayServer *server)
 gboolean
 display_server_get_is_ready (DisplayServer *server)
 {
+    DisplayServerPrivate *priv = display_server_get_instance_private (server);
     g_return_val_if_fail (server != NULL, FALSE);
-    return server->priv->is_ready;
+    return priv->is_ready;
 }
 
 static gboolean
 display_server_real_start (DisplayServer *server)
 {
-    server->priv->is_ready = TRUE;
+    DisplayServerPrivate *priv = display_server_get_instance_private (server);
+    priv->is_ready = TRUE;
     g_signal_emit (server, signals[READY], 0);
     return TRUE;
 }
@@ -129,11 +132,13 @@ display_server_real_disconnect_session (DisplayServer *server, Session *session)
 void
 display_server_stop (DisplayServer *server)
 {
+    DisplayServerPrivate *priv = display_server_get_instance_private (server);
+
     g_return_if_fail (server != NULL);
 
-    if (server->priv->stopping)
+    if (priv->stopping)
         return;
-    server->priv->stopping = TRUE;
+    priv->stopping = TRUE;
 
     DISPLAY_SERVER_GET_CLASS (server)->stop (server);
 }
@@ -141,8 +146,9 @@ display_server_stop (DisplayServer *server)
 gboolean
 display_server_get_is_stopping (DisplayServer *server)
 {
+    DisplayServerPrivate *priv = display_server_get_instance_private (server);
     g_return_val_if_fail (server != NULL, FALSE);
-    return server->priv->stopping;
+    return priv->stopping;
 }
 
 static void
@@ -154,7 +160,6 @@ display_server_real_stop (DisplayServer *server)
 static void
 display_server_init (DisplayServer *server)
 {
-    server->priv = G_TYPE_INSTANCE_GET_PRIVATE (server, DISPLAY_SERVER_TYPE, DisplayServerPrivate);
 }
 
 static void
@@ -168,8 +173,6 @@ display_server_class_init (DisplayServerClass *klass)
     klass->disconnect_session = display_server_real_disconnect_session;
     klass->stop = display_server_real_stop;
 
-    g_type_class_add_private (klass, sizeof (DisplayServerPrivate));
-
     signals[READY] =
         g_signal_new (DISPLAY_SERVER_SIGNAL_READY,
                       G_TYPE_FROM_CLASS (klass),
