@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2010-2011 Robert Ancell.
  * Author: Robert Ancell <robert.ancell@canonical.com>
- * 
+ *
  * This program is free software: you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free Software
  * Foundation, either version 3 of the License, or (at your option) any later
@@ -9,9 +9,9 @@
  * license.
  */
 
-#ifndef _SESSION_CHILD_H_
-#define _SESSION_CHILD_H_
+#ifndef SESSION_CHILD_H_
+#define SESSION_CHILD_H_
 
 int session_child_run (int argc, char **argv);
 
-#endif /* _SESSION_CHILD_H_ */
+#endif /* SESSION_CHILD_H_ */
